from ._models import Document as DocumentGenerated
from ._models import InvoiceData, JobDescriptionData, ResumeData


class Document(DocumentGenerated):
    def _validate_document_type(self, expected: str) -> bool:
        """
        Return `True` if the extractor is defined and has the identifier equal to `expected`
        """
        if self.meta.collection is None:
            return False
        if self.meta.collection.extractor is None:
            return False
        return self.meta.collection.extractor.identifier == expected

    def as_resume(self):
        """
        Convert the `data` of this document to an ~affinda.models.ResumeData

        :raises: ValueError if this document does not appear to be a resume
        :raises: ~msrest.exceptions.DeserializationError if something went wrong
        :raises: ~msrest.exceptions.SerializationError if something went wrong
        """
        if not self._validate_document_type("resume"):
            raise ValueError("Document does not appear to be a resume")
        if self.data:
            self.data = ResumeData.deserialize(self.data)

    def as_invoice(self):
        """
        Convert the `data` of this document to an ~affinda.models.InvoiceData

        :raises: ValueError if this document does not appear to be an invoice
        :raises: ~msrest.exceptions.DeserializationError if something went wrong
        :raises: ~msrest.exceptions.SerializationError if something went wrong
        """
        if not self._validate_document_type("invoice"):
            raise ValueError("Document does not appear to be an invoice")
        if self.data:
            self.data = InvoiceData.deserialize(self.data)

    def as_job_description(self):
        """
        Convert the `data` of this document to an ~affinda.models.JobDescriptionData

        :raises: ValueError if this document does not appear to be a job description
        :raises: ~msrest.exceptions.DeserializationError if something went wrong
        :raises: ~msrest.exceptions.SerializationError if something went wrong
        """
        if not self._validate_document_type("job-description"):
            raise ValueError("Document does not appear to be a job description")
        if self.data:
            self.data = JobDescriptionData.deserialize(self.data)


def patch_sdk():
    """Do not remove from this file.

    `patch_sdk` is a last resort escape hatch that allows you to do customizations
    you can't accomplish using the techniques described in
    https://aka.ms/azsdk/python/dpcodegen/python/customize
    """


__all__ = ["Document"]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.9.4, generator: @autorest/python@5.16.0)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class EducationLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    SCHOOL = "school"
    CERTIFICATE = "certificate"
    BACHELORS = "bachelors"
    MASTERS = "masters"
    DOCTORAL = "doctoral"


class Enum3(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class Enum6(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class GetResponses200ContentApplicationJsonSchemaResultsItemDocumentType(
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class ManagementLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    NONE = "None"
    LOW = "Low"
    MID = "Mid"
    UPPER = "Upper"


class PostContentSchemaDocumentType(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class Region(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """region - server parameter"""

    API = "api"
    API_EU1 = "api.eu1"


class ResthookEvent(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The event name to subscribe to."""

    RESUME_PARSE_SUCCEEDED = "resume.parse.succeeded"
    RESUME_PARSE_FAILED = "resume.parse.failed"
    RESUME_PARSE_COMPLETED = "resume.parse.completed"
    INVOICE_PARSE_SUCCEEDED = "invoice.parse.succeeded"
    INVOICE_PARSE_FAILED = "invoice.parse.failed"
    INVOICE_PARSE_COMPLETED = "invoice.parse.completed"
    INVOICE_VALIDATE_COMPLETED = "invoice.validate.completed"
    DOCUMENT_PARSE_SUCCEEDED = "document.parse.succeeded"
    DOCUMENT_PARSE_FAILED = "document.parse.failed"
    DOCUMENT_PARSE_COMPLETED = "document.parse.completed"
    DOCUMENT_VALIDATE_COMPLETED = "document.validate.completed"
    DOCUMENT_CLASSIFY_SUCCEEDED = "document.classify.succeeded"
    DOCUMENT_CLASSIFY_FAILED = "document.classify.failed"
    DOCUMENT_CLASSIFY_COMPLETED = "document.classify.completed"


class ResthookSubscriptionVersion(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Version of the resthook subscription. Determines the resthook body being fired."""

    V1 = "v1"
    V2 = "v2"
    V3 = "v3"


class ResumeSearchParametersCustomDataFilterType(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    EQUALS = "equals"
    RANGE = "range"


class ResumeSkillSourcesItemSection(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    ACHIEVEMENTS = "Achievements"
    ADDITIONAL_INFORMATION = "AdditionalInformation"
    EDUCATION = "Education"
    EXTRACURRICULARS = "Extracurriculars"
    ORGANISATIONS = "Organisations"
    OTHER = "Other"
    PERSONAL_DETAILS = "PersonalDetails"
    PROJECTS = "Projects"
    PUBLICATIONS = "Publications"
    REFEREES = "Referees"
    SKILLS = "Skills"
    SUMMARY = "Summary"
    TRAINING = "Training"
    WORK_EXPERIENCE = "WorkExperience"
    NOT_POPULATED = "NotPopulated"
    HEADER = "Header"
    FOOTER = "Footer"
    SKILLS_INTERESTS_LANGUAGES = "Skills/Interests/Languages"
    TRAINING_CERTIFICATIONS = "Training/Certifications"
    EXTRACURRICULARS_LEADERSHIP = "Extracurriculars/Leadership"


class SearchLocationUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    KM = "km"
    MI = "mi"


class Version(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Version of the resthook subscription. Determines the resthook body being fired."""

    V1 = "v1"
    V2 = "v2"
    V3 = "v3"
